-- RangeRecolor
-- by CrowGoblin

local RangeRecolorName = "RangeRecolor";
local RangeRecolorVersion = 2.5;
local isLoaded = false;

local	RangeRecolorColorRed = { r = 0.8, g = 0.1, b = 0.1 };
local	RangeRecolorColorNoMana = { r = 0.4, g = 0.4, b = 1.0 };
local	RangeRecolorColorInvalid = { r = 0.4, g = 0.4, b = 0.4 };
local	RangeRecolorColorBorder = { r = 0.4, g = 0.4, b = 0.4 };


function RangeRecolorOptions_Defaults()
	RangeRecolorColorRed = RangeRecolorColorRed;
	RangeRecolorColorBorder = RangeRecolorColorBorder;
	RangeRecolorColorNoMana = RangeRecolorColorNoMana;
	RangeRecolorColorInvalid = RangeRecolorColorInvalid;
	--RangeRecolorOptions_Show();
end


local function SetHook(myFunction, HookFunc)
	local oldFunction = getglobal(HookFunc);
	local newFunction =
		function(e)
			oldFunction(e);
			myFunction(e);
		end
	setglobal(HookFunc, newFunction);
end


function RangeRecolorAction_OnLoad()

	this:RegisterEvent("VARIABLES_LOADED");
	this:RegisterEvent("UNIT_NAME_UPDATE");
	this:RegisterEvent("PLAYER_TARGET_CHANGED");

	-- Set Default
		RangeRecolorColorRed = RangeRecolorColorRed;
		RangeRecolorColorBorder = RangeRecolorColorBorder;
		RangeRecolorColorNoMana = RangeRecolorColorNoMana;
		RangeRecolorColorInvalid = RangeRecolorColorInvalid;

	-- Add RangeRecolor frame to the UIPanelWindows list
	UIPanelWindows["RangeRecolorOptions"] = {area = "center", pushable = 0};

	if ( DEFAULT_CHAT_FRAME ) then
		DEFAULT_CHAT_FRAME:AddMessage(string.format("RangeRecolor loaded"),1.0,1.0,1.0);
	end
	
	SlashCmdList["RangeRecolorCMD"] = RangeRecolor_Command;
	SLASH_RangeRecolorCMD1 = "/rr";
end

function RangeRecolorAction_OnEvent(event)
	if (event=="VARIABLES_LOADED") then
		RangeRecolorAction_Setup();
	end

	if(isLoaded) then RangeRecolorAction_Setup(); end

end

-- Command parser
function RangeRecolor_Command(msg)
	if (msg==nil) then
		msg = "";
	end
	msg = string.lower(msg);
	
	-- configure?
	if(string.find(msg, '')) then
		
	end
	RangeRecolorAction_Setup();
end


function RangeRecolorAction_Setup()	
	isLoaded = false;
	

	if ( SizeUpGizmoConfig.range == false ) then
		return;
	end

	-- Hook Standard Buttons
	SetHook(RangeRecolorAction_OnUpdate, "ActionButton_OnUpdate");
	SetHook(RangeRecolorAction_UpdateUsable, "ActionButton_UpdateUsable");
	local hooks = "Standard Bar";

end


function RangeRecolorAction_UpdateUsable(arg)

	if ( SizeUpGizmoConfig.range == false ) then
		return;
	end
	
	-- Get the Icon and Normal Texture for the Action Button
	local icon = getglobal(this:GetName().."Icon");
	local normalTexture = getglobal(this:GetName().."NormalTexture");

	-- Check if its usable (from original func) no sense in range checking if its not
	local isUsable, notEnoughMana = IsUsableAction(ActionButton_GetPagedID(this));

	-- Add a red border
	local border = getglobal(this:GetName().."Border");

	if (icon and normalTexture) then
	if ( IsActionInRange(ActionButton_GetPagedID(this)) == 0 ) then
			icon:SetVertexColor(RangeRecolorColorRed.r, RangeRecolorColorRed.g, RangeRecolorColorRed.b);
			normalTexture:SetVertexColor(1.0, 1.0, 1.0);
	else
		if ( isUsable ) then
			icon:SetVertexColor(1.0, 1.0, 1.0);
			normalTexture:SetVertexColor(1.0, 1.0, 1.0);
		elseif ( notEnoughMana ) then
			icon:SetVertexColor(RangeRecolorColorNoMana.r, RangeRecolorColorNoMana.g, RangeRecolorColorNoMana.b);
			normalTexture:SetVertexColor(1.0, 1.0, 1.0);
		else
			icon:SetVertexColor(0.4, 0.4, 0.4);
			normalTexture:SetVertexColor(1.0, 1.0, 1.0);
		end
	end
	end
end


-- Update Function, sent elapsed time since last update (ms)
function RangeRecolorAction_OnUpdate(elapsed)

	if ( SizeUpGizmoConfig.range == false ) then
		return;
	end
		
	-- Get the Icon and Normal Texture for the Action Button
	local icon = getglobal(this:GetName().."Icon");
	local normalTexture = getglobal(this:GetName().."NormalTexture");

	-- Check if its usable (from original func) no sense in range checking if its not
	local isUsable, notEnoughMana = IsUsableAction(ActionButton_GetPagedID(this));

	-- Add a red border if button
	local border = getglobal(this:GetName().."Border");


	if ( this.rangeTimer ) then
		if ( this.rangeTimer <= elapsed ) then
			ActionButton_UpdateUsable();

			if ( IsActionInRange(ActionButton_GetPagedID(this)) == 0 ) then
					icon:SetVertexColor(RangeRecolorColorRed.r, RangeRecolorColorRed.g, RangeRecolorColorRed.b);
					normalTexture:SetVertexColor(1.0, 1.0, 1.0);
			else
				if ( isUsable ) then
					icon:SetVertexColor(1.0, 1.0, 1.0);
					normalTexture:SetVertexColor(1.0, 1.0, 1.0);
				elseif ( notEnoughMana ) then
					icon:SetVertexColor(RangeRecolorColorNoMana.r, RangeRecolorColorNoMana.g, RangeRecolorColorNoMana.b);
					normalTexture:SetVertexColor(1.0, 1.0, 1.0);
				else
					icon:SetVertexColor(0.4, 0.4, 0.4);
					normalTexture:SetVertexColor(1.0, 1.0, 1.0);
				end
			end

			this.rangeTimer = TOOLTIP_UPDATE_TIME;
		else
			this.rangeTimer = this.rangeTimer - elapsed;
		end
	end

end
